@@ -1,9 +1,9 @@
 package Sah::Schema::cryptoexchange::account;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-11-29'; # DATE
+our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-App-cryp'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [str => {
     summary => 'Account at a cryptocurrency exchange',
@@ -18,6 +18,29 @@ optional and will be assumed to be "/default" if not specified.
 _
     'x.completion' => 'cryptoexchange_account',
     'x.perl.coerce_rules' => ['From_str::normalize_cryptoexchange_account'],
+    examples => [
+        {
+            summary => 'Invalid account syntax',
+            data    => 'indodax/a b',
+            valid   => 0,
+        },
+        {
+            summary => 'Account too long',
+            data    => 'indodax/'.('a' x 65),
+            valid   => 0,
+        },
+        {
+            summary => 'Unknown cryptoexchange',
+            data    => 'foo/acc1',
+            valid   => 0,
+        },
+        {
+            summary => 'Valid',
+            data    => 'indodax',
+            valid   => 1,
+            res     => 'indodax/default',
+        },
+    ],
 }, {}];
 
 1;
@@ -35,7 +58,7 @@ Sah::Schema::cryptoexchange::account - Account at a cryptocurrency exchange
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2019-11-29.
+This document describes version 0.005 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
@@ -67,7 +90,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
